@@ -29,11 +29,12 @@
 .onLoad <- function(libname, pkgname) {
   
   javaCheck <- function() {
-    # Java version check, without .jinit (we do .jpackage after downloading resources)
+    # Java version check, without initializing rJava (we can only do .jpackage(...) after downloading resources below)
     rawVersion <- system2("java", c("-version"), stdout = TRUE, stderr = TRUE)
-    jv <- regmatches(rawVersion[1], regexpr("[0-9\\.]+", rawVersion[1]))
+    versionLines <- rawVersion[!grepl("Picked up", rawVersion)] # ignore java environment variables being logged
+    jv <- regmatches(versionLines[1], regexpr("[0-9\\.]+", versionLines[1]))
     if (nchar(jv)<1) {
-      stop(paste0("unable to parse java version from", paste0(rawVersion, collapse=" "), "; is java installed correctly ?"))
+      stop(paste0("unable to parse java version from", paste0(versionLines, collapse=" "), "; is java installed correctly ?"))
     }
     else if(nchar(jv)==1) {
        jvn <- as.numeric(jv)
@@ -46,7 +47,7 @@
         jvn <- as.numeric(twoFirst)
       }
     }
-    if (jvn<8 || jvn>17) stop(paste0("XLConnect is compatible with Java versions 8 to 16. Detected java version: ",jv))
+    if (jvn<8) stop(paste0("XLConnect is compatible with Java versions 8 and above. Detected java version: ",jv))
   }
   javaCheck()
   repo <- Sys.getenv("XLCONNECT_JAVA_REPO_URL")
@@ -57,32 +58,35 @@
   sharedPaths <- tryCatch({
     c(
       xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml-schemas/4.1.2/poi-ooxml-schemas-4.1.2.jar"), "poi-ooxml-schemas.jar", 
-      "4\\.[1-9].*",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi-ooxml-full/5.2.3/poi-ooxml-full-5.2.3.jar"), "poi-ooxml-full.jar", 
+      "5.2.3",  libname, pkgname),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi-ooxml/4.1.2/poi-ooxml-4.1.2.jar"), "poi-ooxml.jar", 
-      "4\\.[1-9].*",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi-ooxml/5.2.3/poi-ooxml-5.2.3.jar"), "poi-ooxml.jar", 
+      "5.2.3",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/poi/4.1.2/poi-4.1.2.jar"), "poi.jar", 
-      "4\\.[1-9].*",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
+      paste0(apachePrefix, "/poi/poi/5.2.3/poi-5.2.3.jar"), "poi.jar", 
+      "5.2.3",  libname, pkgname, debianpkg = "libapache-poi-java", rpmpkg="apache-poi"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/commons/commons-compress/1.20/commons-compress-1.20.jar"), "commons-compress.jar",
+      paste0(apachePrefix, "/commons/commons-compress/1.21/commons-compress-1.21.jar"), "commons-compress.jar",
       "1\\.(1[8-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg = "libcommons-compress-java", rpmpkg="apache-commons-compress"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/xmlbeans/xmlbeans/3.1.0/xmlbeans-3.1.0.jar"), "xmlbeans.jar",
-      "3\\..*",  libname, pkgname, debianpkg="libxmlbeans-java"),
+      paste0(apachePrefix, "/xmlbeans/xmlbeans/5.0.3/xmlbeans-5.0.3.jar"), "xmlbeans.jar",
+      "5\\..*",  libname, pkgname, debianpkg="libxmlbeans-java"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/commons/commons-collections4/4.4/commons-collections4-4.4.jar"), "commons-collections4.jar",
       "4-4\\.([2-9]|1[0-9]).*",  libname, pkgname, debianpkg="libcommons-collections4-java", rpmpkg="apache-commons-collections4"),
     xlcEnsureDependenciesFor(
       paste0(apachePrefix, "/commons/commons-math3/3.6.1/commons-math3-3.6.1.jar"), "commons-math3.jar",
       "3\\.([6-9]|1[0-9]).*",  libname, pkgname, debianpkg="libcommons-math3-java"),
+    xlcEnsureDependenciesFor(
+      paste0(apachePrefix, "/logging/log4j/log4j-api/2.17.2/log4j-api-2.17.2.jar"), "log4j-api.jar",
+      "2.17.2",  libname, pkgname),
     xlcEnsureDependenciesFor(
       paste0(repo, "/commons-codec/commons-codec/1.15/commons-codec-1.15.jar"), "commons-codec-1.15.jar",
       "1\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-codec-java", rpmpkg="apache-commons-codec"),
     xlcEnsureDependenciesFor(
-      paste0(apachePrefix, "/poi/ooxml-schemas/1.4/ooxml-schemas-1.4.jar"), "ooxml-schemas.jar",
-      "1\\.([4-9]|[1-9][0-9]).*",  libname, pkgname),
+      paste0(repo, "/commons-io/commons-io/2.11.0/commons-io-2.11.0.jar"), "commons-io-2.11.0.jar",
+      "2\\.(1[1-9]|[2-9][0-9]).*",  libname, pkgname, debianpkg="libcommons-io-java", rpmpkg="apache-commons-io"),
     xlcEnsureDependenciesFor(
       paste0(repo, "/com/zaxxer/SparseBitSet/1.2/SparseBitSet-1.2.jar"), "SparseBitSet.jar",
       "1\\.([2-9]|[1-9][0-9]).*",  libname, pkgname)
@@ -92,7 +96,7 @@
           e
         }
   )
-  .jpackage(name = pkgname, jars = "*", morePaths = sharedPaths)
+  .jpackage(name = pkgname, jars = "*", morePaths = sharedPaths, own.loader=TRUE)  
   # Perform general XLConnect settings - pass package description
   XLConnectSettings(packageDescription(pkgname))
 }
